@@ -1,7 +1,8 @@
 use std::{iter::once, mem};
 use swc_common::{Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::perf::{should_work, Check};
+use swc_ecma_transforms_base::perf::Check;
+use swc_ecma_transforms_macros::fast_path;
 use swc_ecma_utils::{alias_if_required, prepend, private_ident, undefined, ExprFactory, StmtLike};
 use swc_ecma_visit::{noop_fold_type, noop_visit_type, Fold, FoldWith, Node, Visit};
 
@@ -16,14 +17,11 @@ struct OptChaining {
 }
 
 /// TODO: VisitMut
+#[fast_path(ShouldWork)]
 impl Fold for OptChaining {
     noop_fold_type!();
 
     fn fold_block_stmt_or_expr(&mut self, e: BlockStmtOrExpr) -> BlockStmtOrExpr {
-        if !should_work::<ShouldWork, _>(&e) {
-            return e;
-        }
-
         match e {
             BlockStmtOrExpr::BlockStmt(..) => e.fold_children_with(self),
             BlockStmtOrExpr::Expr(e) => {
@@ -43,10 +41,6 @@ impl Fold for OptChaining {
     }
 
     fn fold_expr(&mut self, e: Expr) -> Expr {
-        if !should_work::<ShouldWork, _>(&e) {
-            return e;
-        }
-
         let e = match e {
             Expr::OptChain(e) => Expr::Cond(self.unwrap(e)),
             Expr::Unary(e) => self.handle_unary(e),
